ohmcli

package
v0.10.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package ohmcli assembles the Ohm framework command-line interface.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(opts ...Option) *cli.Program

New returns the Ohm framework CLI program.

Types

type Option

type Option func(*options)

Option configures the Ohm framework CLI.

func WithIO

func WithIO(commandIO cli.IO) Option

WithIO configures command input and output streams.

func WithOhmVersion

func WithOhmVersion(version string) Option

WithOhmVersion configures the Ohm module version written to generated apps.

func WithVersion

func WithVersion(version string) Option

WithVersion configures the version printed by the framework CLI.

Jump to