Documentation
¶
Overview ¶
Package env parses, loads, and applies Ohm environment files.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultFiles ¶
DefaultFiles returns the default environment file load order.
Types ¶
type Loader ¶
type Loader struct {
Dir string
Environment string
Files []string
LookupEnv func(string) (string, bool)
SetEnv func(string, string) error
}
Loader reads Ohm environment files from a directory.
func (Loader) Apply ¶
Apply sets loaded values without overwriting existing process environment values.
type ParseError ¶
ParseError describes an invalid line in an environment file.
func (*ParseError) Error ¶
func (e *ParseError) Error() string
Error returns the formatted parse location and message.
Click to show internal directories.
Click to hide internal directories.