Documentation
¶
Overview ¶
Package ohmcli assembles the Ohm framework command-line interface.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Option ¶
type Option func(*options)
Option configures the Ohm framework CLI.
func WithOhmVersion ¶
WithOhmVersion configures the Ohm module version written to generated apps.
func WithVersion ¶
WithVersion configures the version printed by the framework CLI.
Click to show internal directories.
Click to hide internal directories.